summaryrefslogtreecommitdiffstats
path: root/examples/widgets/painting/basicdrawing/renderarea.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/widgets/painting/basicdrawing/renderarea.cpp')
-rw-r--r--examples/widgets/painting/basicdrawing/renderarea.cpp14
1 files changed, 8 insertions, 6 deletions
diff --git a/examples/widgets/painting/basicdrawing/renderarea.cpp b/examples/widgets/painting/basicdrawing/renderarea.cpp
index e3e6771b4f..6a68389ee7 100644
--- a/examples/widgets/painting/basicdrawing/renderarea.cpp
+++ b/examples/widgets/painting/basicdrawing/renderarea.cpp
@@ -1,7 +1,7 @@
/****************************************************************************
**
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
**
** This file is part of the examples of the Qt Toolkit.
**
@@ -17,9 +17,9 @@
** notice, this list of conditions and the following disclaimer in
** the documentation and/or other materials provided with the
** distribution.
** * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
** of its contributors may be used to endorse or promote products derived
** from this software without specific prior written permission.
**
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
@@ -189,7 +189,9 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
painter.drawPath(path);
break;
case Text:
- painter.drawText(rect, Qt::AlignCenter, tr("Qt by\nDigia"));
+ painter.drawText(rect,
+ Qt::AlignCenter,
+ tr("Qt by\nThe Qt Company"));
break;
case Pixmap:
painter.drawPixmap(10, 10, pixmap);
@@ -17,9 +17,9 @@
** the documentation and/or other materials provided with the
** distribution.
-** * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
-** of its contributors may be used to endorse or promote products derived
-** from this software without specific prior written permission.
+** * Neither the name of The Qt Company Ltd and its Subsidiary(-ies) nor the
+** names of its contributors may be used to endorse or promote products
+** derived from this software without specific prior written permission.
**
**